'A reference to the Phidget22.NET.dll must be added to new projects in VB.Net 
'From the "Project" menu select "Add Reference" 
'From the "Add Reference" window select the "Browse" tab 
'Browse to the directory you installed the Phidgets library to 
'The default is "C:\Program Files\Phidgets" 
'Select "Phidget22.NET.dll" and click "OK" 
'To view objects that have been added, select the "View" menu 
'Select "Object Browser" 
'Then expand the Phidget22.NET.dll item 



Imports Phidget22
Imports Phidget22.Events
Imports System.Linq

Public Class Form1
    Dim WithEvents device As Phidget22.VoltageInput
    Dim open As ExampleUtils.ExampleUtils.CommandLineOpen
    Dim errorBox As ErrorEventBox

    Public Sub New()
        open = New ExampleUtils.ExampleUtils.CommandLineOpen(Me)
        Phidget22.Phidget.InvokeEventCallbacks = True
        InitializeComponent()
    End Sub

    Public Sub New(ByVal commandLine As String())
        open = New ExampleUtils.ExampleUtils.CommandLineOpen(Me)
        open.commandLine = commandLine
        Phidget22.Phidget.InvokeEventCallbacks = True
        InitializeComponent()
    End Sub

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        errorBox = New ErrorEventBox(Me)
        device = New Phidget22.VoltageInput()

        Dim phidgetParameters As ExampleUtils.commandLineData = open.parseCmdLine()

        Try 'set all the values grabbed from command line.  these values have defaults that are set in ExampleUtils.vb, you can check there to see them
            device.Channel = phidgetParameters.Channel 'selects the channel on the device to open
            device.DeviceSerialNumber = phidgetParameters.SerialNumber 'selects the device or hub to open
            device.HubPort = phidgetParameters.HubPort 'selects th eport on the hub to open
            device.IsHubPortDevice = phidgetParameters.isHubPortDevice 'is the device a port on a vint hub?

            If phidgetParameters.isRemote Then 'are we trying to open a remote device?
                device.IsRemote = True
                Net.EnableServerDiscovery(ServerType.Device) 'turn on network scan
                If phidgetParameters.Password <> vbNullString And phidgetParameters.ServerName <> vbNullString Then
                    Net.SetServerPassword(phidgetParameters.ServerName, phidgetParameters.Password)
                End If
            Else
                device.IsLocal = True
            End If

            device.Open() 'open the device specified by the above parameters
        Catch ex As PhidgetException
            errorBox.addMessage("Error opening the device: " + ex.Message)
        End Try
    End Sub

    Private Sub Form1_FormClosing(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
        Application.DoEvents()
        If device.Attached Then
            device.Close()
        End If
    End Sub

    Private Sub Clear()
        PhidgetInfoBox1.Clear()

        settingsBox.Visible = False
        voltage_range_panel.Visible = False
        pwr_supply_panel.Visible = False
        dataBox.Visible = False
        sensorTypeLbl.Visible = False
        sensorTypeCmb.Visible = False
        sensor_value_panel.Visible = False
    End Sub

    Private Sub device_Attach(ByVal sender As Object, ByVal e As Phidget22.Events.AttachEventArgs) Handles device.Attach
        Dim attachedDevice As VoltageInput = CType(sender, VoltageInput)
        PhidgetInfoBox1.FillPhidgetInfo(attachedDevice)


        Try
            dataIntervalTrk.Unit = "ms"
            dataIntervalTrk.minTxt = attachedDevice.MinDataInterval.ToString()
            dataIntervalTrk.Minimum = attachedDevice.MinDataInterval
            dataIntervalTrk.maxTxt = attachedDevice.MaxDataInterval.ToString()
            dataIntervalTrk.Maximum = attachedDevice.MaxDataInterval

            'differing max/min means the interval Is a settable configuration
            If attachedDevice.MaxDataInterval = attachedDevice.MinDataInterval Then
                dataIntervalTrk.Enabled = False
            Else
                dataIntervalTrk.Enabled = True
                dataIntervalTrk.Value = attachedDevice.DataInterval
            End If
        Catch ex As Exception
            errorBox.addMessage("Error setting interval: " + ex.Message)
        End Try

        Try
            changeTriggerTrk.Unit = "V"
            changeTriggerTrk.minTxt = attachedDevice.MinVoltageChangeTrigger.ToString()
            changeTriggerTrk.Minimum = attachedDevice.MinVoltageChangeTrigger
            changeTriggerTrk.Maximum = attachedDevice.MaxVoltageChangeTrigger
            changeTriggerTrk.maxTxt = attachedDevice.MaxVoltageChangeTrigger.ToString()

            'differeing max/min means the trigger is a settable configuration
            If (attachedDevice.MaxDataInterval = attachedDevice.MinDataInterval) Then
                changeTriggerTrk.Enabled = False
            Else
                changeTriggerTrk.Value = 0
            End If
        Catch ex As PhidgetException
            errorBox.addMessage("Error setting change trigger: " + ex.Message)
        End Try

        'set up form according to device.  Note that we set combo box values, which set the Phidget properties in the combo box change events.
        Dim supportedVoltageRanges As [Enum]()
        Dim supportedSensorTypes As [Enum]()

        Select Case (device.DeviceID) 'configure form based on the device detected
            Case DeviceID.PN_1058
                sensorTypeLbl.Visible = True
                sensorTypeCmb.Visible = True
                sensor_value_panel.Visible = True
                supportedSensorTypes = New [Enum]() {Phidget22.VoltageSensorType.Voltage}
                sensorTypeCmb.DataSource = supportedSensorTypes.ToList()
                sensorTypeCmb.SelectedValue = Phidget22.VoltageSensorType.Voltage
            Case DeviceID.PN_ADP1000
                voltage_range_panel.Visible = True
                supportedVoltageRanges = New [Enum]() {Phidget22.VoltageRange.MilliVolts_400,
                                                       Phidget22.VoltageRange.Volts_2}
                voltageRangeCmb.DataSource = supportedVoltageRanges.ToList()
                voltageRangeCmb.SelectedValue = Phidget22.VoltageRange.MilliVolts_400

                sensorTypeLbl.Visible = True
                sensorTypeCmb.Visible = True
                sensor_value_panel.Visible = True
                supportedSensorTypes = New [Enum]() {Phidget22.VoltageSensorType.Voltage}
                sensorTypeCmb.DataSource = supportedSensorTypes.ToList()
                sensorTypeCmb.SelectedValue = Phidget22.VoltageSensorType.Voltage
            Case DeviceID.PN_DAQ1400
                pwr_supply_panel.Visible = True
                powerSupplyCmb.DataSource = [Enum].GetValues(GetType(PowerSupply))
                powerSupplyCmb.SelectedValue = PowerSupply.Off
            Case DeviceID.PN_VCP1000
                voltage_range_panel.Visible = True
                supportedVoltageRanges = New [Enum]() {Phidget22.VoltageRange.MilliVolts_312_5,
                                                       Phidget22.VoltageRange.Volts_40}
                voltageRangeCmb.DataSource = supportedVoltageRanges.ToList()
                voltageRangeCmb.SelectedValue = Phidget22.VoltageRange.Volts_40
            Case DeviceID.PN_VCP1001
                voltage_range_panel.Visible = True
                supportedVoltageRanges = New [Enum]() {Phidget22.VoltageRange.Volts_5,
                                                       Phidget22.VoltageRange.Volts_15,
                                                       Phidget22.VoltageRange.Volts_40,
                                                       Phidget22.VoltageRange.Auto}
                voltageRangeCmb.DataSource = supportedVoltageRanges.ToList()
                voltageRangeCmb.SelectedValue = Phidget22.VoltageRange.Auto
            Case DeviceID.PN_VCP1002
                voltage_range_panel.Visible = True
                supportedVoltageRanges = New [Enum]() {Phidget22.VoltageRange.MilliVolts_10,
                                                       Phidget22.VoltageRange.MilliVolts_40,
                                                       Phidget22.VoltageRange.MilliVolts_200,
                                                       Phidget22.VoltageRange.MilliVolts_1000,
                                                       Phidget22.VoltageRange.Auto}
                voltageRangeCmb.DataSource = supportedVoltageRanges.ToList()
                voltageRangeCmb.SelectedValue = Phidget22.VoltageRange.Auto
            Case DeviceID.VoltageInputPort, DeviceID.PN_DAQ1000, DeviceID.PN_1011, DeviceID.PN_1010_1013_1018_1019, DeviceID.PN_1202_1203, DeviceID.PN_1065
                sensorTypeLbl.Visible = True
                sensorTypeCmb.Visible = True
                sensor_value_panel.Visible = True

                Dim supportedSensorTypesList As List(Of [Enum]) = ([Enum].GetValues(GetType(Phidget22.VoltageSensorType))).Cast(Of [Enum]).ToList()
                sensorTypeCmb.DataSource = ExampleUtils.EnumHelper.ToList(supportedSensorTypesList.ToArray) 'appears superfluous but this actually adds the descriptions to the list by using the helper function in ExampleUtils
                sensorTypeCmb.SelectedValue = Phidget22.VoltageSensorType.Voltage
            Case DeviceID.PN_1048
                'do nothing
            Case Else
                If attachedDevice.ChannelSubclass = ChannelSubclass.VoltageInputSensorPort Then
                    sensorTypeCmb.DataSource = ExampleUtils.EnumHelper.ToList([Enum].GetValues(GetType(Phidget22.VoltageRatioSensorType)).Cast(Of [Enum]).ToArray()) 'appears redundant but this adds the description to the array elements by using the ToList from ExampleUtils rather than standard libraries.
                    sensorTypeCmb.Show()
                    sensor_value_panel.Show()
                    sensorTypeCmb.SelectedIndex = 0
                End If
        End Select

        settingsBox.Visible = True
        dataBox.Visible = True
    End Sub

    Private Sub device_Detach(ByVal sender As Object, ByVal e As Phidget22.Events.DetachEventArgs) Handles device.Detach
        Clear()
    End Sub

    Private Sub device_Error(ByVal sender As Object, ByVal e As Phidget22.Events.ErrorEventArgs) Handles device.Error
        errorBox.addMessage(e.Description)
    End Sub

    Private Sub device_VoltageChange(ByVal sender As Object, ByVal e As Phidget22.Events.VoltageInputVoltageChangeEventArgs) Handles device.VoltageChange
        Try
            voltageTxt.Text = device.Voltage.ToString() + " V"
        Catch ex As Exception
            errorBox.addMessage("Error reading voltage: " + ex.Message)
        End Try
    End Sub

    Private Sub device_SensorChange(ByVal sender As Object, ByVal e As Phidget22.Events.VoltageInputSensorChangeEventArgs) Handles device.SensorChange
        Try
            sensorTxt.Text = device.SensorValue.ToString() + " " + device.SensorUnit.ToString()
        Catch ex As PhidgetException
            errorBox.addMessage("Error reading sensor value: " + ex.Message)
        End Try
    End Sub

    Private Sub voltageRangeCmb_SelectedIndexChanged(sender As Object, e As EventArgs) Handles voltageRangeCmb.SelectedIndexChanged
        Try
            device.VoltageRange = CType([Enum].Parse(GetType(Phidget22.VoltageRange), CType(sender, ComboBox).SelectedValue.ToString()), Phidget22.VoltageSensorType)
        Catch ex As Exception
            errorBox.addMessage("Error setting voltage range: " + ex.Message)
        End Try
    End Sub

    Private Sub powerSupplyCmb_SelectedIndexChanged(sender As Object, e As EventArgs) Handles powerSupplyCmb.SelectedIndexChanged
        Try
            device.PowerSupply = CType([Enum].Parse(GetType(PowerSupply), CType(sender, ComboBox).SelectedValue.ToString()), PowerSupply)
        Catch ex As Exception
            errorBox.addMessage("Error setting power supply: " + ex.Message)
        End Try
    End Sub

    Private Sub sensorTypeCmb_SelectedIndexChanged(sender As Object, e As EventArgs) Handles sensorTypeCmb.SelectedIndexChanged
        Try
            device.SensorType = CType([Enum].Parse(GetType(Phidget22.VoltageSensorType), CType(sender, ComboBox).SelectedValue.ToString()), Phidget22.VoltageSensorType)
        Catch ex As Exception
            errorBox.addMessage("Error setting sensor type: " + ex.Message)
        End Try

        If sensorTypeCmb.SelectedIndex = 0 Then
            label5.Enabled = True ' standard voltage ratio events (i.e. generic sensor type selected)
            voltageTxt.Enabled = True
            sensor_value_panel.Enabled = False

        Else
            label5.Enabled = False 'specific Event For sensor type (this disables normal events)
            voltageTxt.Enabled = False
            sensor_value_panel.Enabled = True
        End If
    End Sub

    Private Sub dataIntervalTrk_Scroll(sender As Object, e As EventArgs) Handles dataIntervalTrk.LogScroll
        If (MouseButtons = MouseButtons.Left) Then
            Try
                device.DataInterval = CType(dataIntervalTrk.Value, Integer)
            Catch ex As Exception
                errorBox.addMessage("Error setting data interval: " + ex.Message)
            End Try
        End If
    End Sub

    Private Sub dataIntervalTrk_LogMouseUp(sender As Object, e As EventArgs) Handles dataIntervalTrk.LogMouseUp
        Try
            device.DataInterval = CType(dataIntervalTrk.Value, Integer)
        Catch ex As Exception
            errorBox.addMessage("Error setting data interval: " + ex.Message)
        End Try
    End Sub

    Private Sub changeTriggertrk_Scroll(sender As Object, e As EventArgs) Handles changeTriggerTrk.LogScroll
        If (MouseButtons = MouseButtons.Left) Then
            Try
                device.VoltageChangeTrigger = CType(changeTriggerTrk.Value, Double)
            Catch ex As Exception
                errorBox.addMessage("Error setting change trigger: " + ex.Message)
            End Try
        End If
    End Sub

    Private Sub changeTriggerTrk_LogMouseUp(sender As Object, e As EventArgs) Handles changeTriggerTrk.LogMouseUp
        Try
            device.VoltageChangeTrigger = CType(changeTriggerTrk.Value, Double)
        Catch ex As Exception
            errorBox.addMessage("Error setting change trigger: " + ex.Message)
        End Try
    End Sub
End Class



